/*
 * Copyright (c) 1997 Motoyuki Kasahara
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <sys/types.h>

#include "eb.h"
#include "error.h"


/*
 * Examine whether the current subbook in `book' supports `EXACTWORD SEARCH'
 * or not.
 */
int
eb_have_exactword_search(book)
    EB_Book *book;
{
    return eb_have_word_search(book);
}


/*
 * Examine whether the current subbook in `book' supports `WORD SEARCH'
 * or not.
 */
int
eb_have_word_search(book)
    EB_Book *book;
{
    /*
     * Current subbook must have been set.
     */
    if (book->subcurrent == NULL) {
	eb_error = EB_ERR_NO_CUR_SUB;
	return 0;
    }

    if (book->subcurrent->indexes[EB_INDEX_WORD_ALPHA] == 0
	&& book->subcurrent->indexes[EB_INDEX_WORD_ASIS] == 0
	&& book->subcurrent->indexes[EB_INDEX_WORD_KANA] == 0) {
	eb_error = EB_ERR_NO_SUCH_SEARCH;
	return 0;
    }

    return 1;
}


/*
 * Examine whether the current subbook in `book' supports `ENDWORD SEARCH'
 * or not.
 */
int
eb_have_endword_search(book)
    EB_Book *book;
{
    /*
     * Current subbook must have been set.
     */
    if (book->subcurrent == NULL) {
	eb_error = EB_ERR_NO_CUR_SUB;
	return 0;
    }

    if (book->subcurrent->indexes[EB_INDEX_ENDWORD_ALPHA] == 0
	&& book->subcurrent->indexes[EB_INDEX_ENDWORD_ASIS] == 0
	&& book->subcurrent->indexes[EB_INDEX_ENDWORD_KANA] == 0) {
	eb_error = EB_ERR_NO_SUCH_SEARCH;
	return 0;
    }

    return 1;
}


/*
 * Examine whether the current subbook in `book' supports `KEYWORD SEARCH'
 * or not.
 */
int
eb_have_keyword_search(book)
    EB_Book *book;
{
    /*
     * Current subbook must have been set.
     */
    if (book->subcurrent == NULL) {
	eb_error = EB_ERR_NO_CUR_SUB;
	return 0;
    }

    if (book->subcurrent->indexes[EB_INDEX_KEYWORD] == 0) {
	eb_error = EB_ERR_NO_SUCH_SEARCH;
	return 0;
    }

    return 1;
}


/*
 * Examine whether the current subbook in `book' supports `MENU SEARCH'
 * or not.
 */
int
eb_have_menu_search(book)
    EB_Book *book;
{
    /*
     * Current subbook must have been set.
     */
    if (book->subcurrent == NULL) {
	eb_error = EB_ERR_NO_CUR_SUB;
	return 0;
    }

    if (book->subcurrent->indexes[EB_INDEX_MENU] == 0) {
	eb_error = EB_ERR_NO_SUCH_SEARCH;
	return 0;
    }

    return 1;
}


/*
 * Examine whether the current subbook in `book' supports `MULTI SEARCH'
 * or not.
 */
int
eb_have_multi_search(book)
    EB_Book *book;
{
    /*
     * Current subbook must have been set.
     */
    if (book->subcurrent == NULL) {
	eb_error = EB_ERR_NO_CUR_SUB;
	return 0;
    }

    if (book->subcurrent->indexes[EB_INDEX_MULTI] == 0) {
	eb_error = EB_ERR_NO_SUCH_SEARCH;
	return 0;
    }

    return 1;
}


/*
 * Examine whether the current subbook in `book' supports `GRAPHIC SEARCH'
 * or not.
 */
int
eb_have_graphic_search(book)
    EB_Book *book;
{
    /*
     * Current subbook must have been set.
     */
    if (book->subcurrent == NULL) {
	eb_error = EB_ERR_NO_CUR_SUB;
	return 0;
    }

    if (book->subcurrent->indexes[EB_INDEX_GRAPHIC] == 0) {
	eb_error = EB_ERR_NO_SUCH_SEARCH;
	return 0;
    }

    return 1;
}


