/*
 * Copyright (c) 1997  Motoyuki Kasahara
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#ifndef READCONF_H
#define READCONF_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

/*
 * Maximum Line length of a configuration file.
 */
#define READCONF_SIZE_LINE	512

/*
 * Maximum Block name in a `Config' structure.
 */
#define READCONF_SIZE_BLKNAME	127

/*
 * Configuration syntax table.
 */
typedef struct {
    /*
     * Block name.
     */
    char *block;

    /*
     * Directive name.
     */
    char *name;

    /*
     * Function to process the directive.
     */
#ifdef __STDC__
    int (*function)(const char *, const char *, const char *, const char *,
	int);
#else
    int (*function)();
#endif

    /*
     * If this flag is set to 1, the directive must be required in a
     * configuration.
     */
    int required;

    /*
     * If this flag is set to 1, the directive can be defined more than
     * once.
     */
    int redefinable;

    /*
     * Directive definition counter.
     * This counter is managed by readconf module.  Don't modify
     * the counter in elsewhere.
     */
    int count;
} Configuration;


#ifdef __STDC__
int read_configuration(const char *filename, Configuration *);
#else /* not __STDC__ */
int read_configuration();
#endif /* not __STDC__ */

#endif /* not READCONF_H */
